@@ -2,9 +2,57 @@ import geopandas as gpd
 import pandas as pd
 from shapely.geometry import Polygon,Point
 from .grids import GPS_to_grids,grids_centre
+from .preprocess import id_reindex
 import math 
 import numpy as np
 
+def traj_densify(data,col = ['Vehicleid','Time','Lng','Lat'],timegap = 15):
+    '''
+    轨迹点增密，确保每隔timegap秒会有一个轨迹点
+    
+    输入
+    -------
+    data : DataFrame
+        数据
+    col : List
+        列名，按[车辆ID,时间,经度,纬度]的顺序
+    timegap : number
+        单位为秒，每隔多长时间插入一个轨迹点
+    
+    输出
+    -------
+    data1 : DataFrame
+        处理后的数据
+    '''
+    Vehicleid,Time,Lng,Lat = col
+    data[Time] = pd.to_datetime(data[Time])
+    data1 = data.copy()
+    data1 = data1.drop_duplicates([Vehicleid,Time])
+    data1 = id_reindex(data1,Vehicleid)
+    data1 = data1.sort_values(by=[Vehicleid+'_new',Time])
+    data1['utctime'] = data1[Time].apply(lambda r:int(r.value/1000000000))
+    data1['utctime_new'] = data1[Vehicleid+'_new']*10000000000+data1['utctime']
+    a = data1.groupby([Vehicleid+'_new'])['utctime'].min().rename('mintime').reset_index()
+    b = data1.groupby([Vehicleid+'_new'])['utctime'].max().rename('maxtime').reset_index()
+    minmaxtime = pd.merge(a,b)
+    mintime = data1['utctime'].min()
+    maxtime = data1['utctime'].max()
+    timedata = pd.DataFrame(range(mintime,maxtime,timegap),columns = [Time])
+    timedata['tmp'] = 1
+    minmaxtime['tmp'] = 1
+    minmaxtime = pd.merge(minmaxtime,timedata)
+    minmaxtime = minmaxtime[(minmaxtime['mintime']<=minmaxtime[Time])&(minmaxtime['maxtime']>=minmaxtime[Time])]
+    minmaxtime['utctime_new'] = minmaxtime[Vehicleid+'_new']*10000000000+minmaxtime[Time]
+    minmaxtime[Time] = pd.to_datetime(minmaxtime[Time],unit = 's')
+    data1 = pd.concat([data1,minmaxtime[['utctime_new',Time]]]).sort_values(by = ['utctime_new'])
+    data1 = data1.drop_duplicates(['utctime_new'])
+    data1[Lng] =data1.set_index('utctime_new')[Lng].interpolate(method = 'index').values
+    data1[Lat] =data1.set_index('utctime_new')[Lat].interpolate(method = 'index').values
+    data1[Vehicleid]=data1[Vehicleid].ffill()
+    data1[Vehicleid]=data1[Vehicleid].bfill()
+    data1 = data1.drop([Vehicleid+'_new','utctime','utctime_new'],axis = 1)
+    return data1
+
 def points_to_traj(traj_points,col = ['Lng','Lat','ID']):
     '''
     输入轨迹点，生成轨迹线型的GeoDataFrame
